Most Stylish New Celebrities of 2014 | Best Dressed Teen Stars | TeenVogue.com
Author: Teen Vogue Magazine
Description: You're going to want to keep an eye out for these stunners in 2015.

Close
Close
Close

##### celebrity-style

# The Top 10 Break-Out Style Stars of 2014

- More

Every year, we love looking back and picking out our favorite red carpet looks from 52 weeks worth of awards shows, highfalutin' fashion events, movie premieres, and every kind of party you can imagine. And while we adore seeing all of our favorite familiar faces, the most exciting moments come from the rookies that are either just hitting the scene this year or just hitting their stride in the style department.

Ahead, we've rounded up our top 10 break-out style star picks for 2014. Click through to see who we chose, and don't forget to nominate your favorites in the comments!

- E-Mail

## You're going to want to keep an eye out for these stunners in 2015.

#####

##

Every year, we love looking back and picking out our favorite red carpet looks from 52 weeks worth of awards shows, highfalutin' fashion events, movie premieres, and every kind of party you can imagine. And while we adore seeing all of our favorite familiar faces, the most exciting moments come from the rookies that are either just hitting the scene this year or just hitting their stride in the style department.

Ahead, we've rounded up our top 10 break-out style star picks for 2014. Click through to see who we chose, and don't forget to nominate your favorites in the comments!

show comments

## What do you think?

#### Post a comment

## You're going to want to keep an eye out for these stunners in 2015.

by Amanda Keiser

#####

##

###